@@ -8,7 +8,7 @@ package IO::Async::Resolver::DNS;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Future;
 use IO::Async::Resolver 0.52; # returns Future
@@ -18,6 +18,12 @@ use Net::DNS;
 
 use List::UtilsBy qw( weighted_shuffle_by );
 
+# Re-export the constants
+use IO::Async::Resolver::DNS::Constants qw( /^ERR_/ );
+
+use Exporter 'import';
+our @EXPORT_OK = @IO::Async::Resolver::DNS::Constants::EXPORT_OK;
+
 =head1 NAME
 
 C<IO::Async::Resolver::DNS> - resolve DNS queries using C<IO::Async>
@@ -222,6 +228,19 @@ sub _extract_SRV
 
 =back
 
+=head1 Error Reporting
+
+The two possible back-end modules that implement the resolver query functions
+provided here differ in their semantics for error reporting. To account for
+this difference and to lead to more portable user code, errors reported by the
+back-end modules are translated to one of the following (exported) constants.
+
+ ERR_NO_HOST        # The specified host name does not exist
+ ERR_NO_ADDRESS     # The specified host name does not provide answers for the
+                      given query type
+ ERR_TEMPORARY      # A temporary failure that may disappear on retry
+ ERR_UNRECOVERABLE  # Any other error
+
 =cut
 
 =head1 RESOLVER METHODS
@@ -257,6 +276,17 @@ argument is not required.
 
 =back
 
+On failure on C<IO::Async> versions that support extended failure results
+(0.68 and later), the extra detail will be an error value matching one of the
+C<ERR_*> constants listed above.
+
+ ->fail( $message, resolve => res_query => $errnum )
+
+Note that due to the two possible back-end implementations it is not
+guaranteed that messages have any particular format; they are intended for
+human consumption only, and the C<$errnum> value should be used for making
+decisions in other code.
+
 When not returning a C<Future>, the following extra arguments are used as
 callbacks instead:
 
